==> haskell-store-0.3-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-store.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: store
version: 0.3
id: store-0.3-Co0MRcThnTK9MVJVPVyIZC
key: store-0.3-Co0MRcThnTK9MVJVPVyIZC
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/store#readme
synopsis: Fast binary serialization
category: Serialization, Data
exposed: True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.Streaming
    Data.Store.Streaming.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer
hidden-modules: Data.Store.Impl
abi: 00b225730a3e9b6cb16ce3e326c32d99
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/store-0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/store-0.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/store-0.3
hs-libraries: HSstore-0.3-Co0MRcThnTK9MVJVPVyIZC
depends:
    array-0.5.1.1 async-2.1.1-9CmNvQft9hOA1w6AR7WdJM base-4.9.0.0
    base-orphans-0.5.4-5IQvrjd7gNP548VkOOyIq6
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 conduit-1.2.9-IqfCpUleYsf85Inkwdla2
    containers-0.5.7.1 cryptohash-0.11.9-58MQCkevJarJihmcTE8nlX
    deepseq-1.4.2.0 directory-1.2.6.2 filepath-1.4.1.0
    free-4.12.4-DZCTkfqdDiF4eKUVutuQ1W ghc-prim-0.5.0.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    hspec-2.4.1-EKirEcV3woaAMgIjGSk9Gu
    hspec-smallcheck-0.4.2-LINiTvGwiLeLagundkG6D2 integer-gmp-1.0.0.1
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mono-traversable-1.0.1.1-7rlAYW3rlGWBRxOTFStZDt
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    safe-0.3.13-Fz8SHW48R8E7ldyMo2658O
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    smallcheck-1.1.1-1P6TVEcRFpCt9hJwyUv6k
    store-core-0.3-DRh8eWR12WHG6VUHAXGWU4
    streaming-commons-0.1.17-JBMCKUjr3AjHIyRG4GSmU7
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    th-lift-0.7.6-3YgW6AFnN6SEjgDav6Czfy
    th-lift-instances-0.1.11-26w65opR3jBHodA1egFP30
    th-orphans-0.13.3-3I3rBAqUDtRC4OurZ5T3Cn
    th-reify-many-0.1.6-LbiUbxB6WW9AOz1EVvH3xI
    th-utilities-0.2.0.1-2u1OccporHjHhMZ0HIeC3K time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    void-0.7.1-7ItcNGyWY8l57cMz7KooSQ
haddock-interfaces: /usr/share/doc/haskell-store/html/store.haddock
haddock-html: /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-store-0.3-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-store.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: store
version: 0.3
id: store-0.3-2cBhM2uItiGHgov5En5NW0
key: store-0.3-2cBhM2uItiGHgov5En5NW0
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/store#readme
synopsis: Fast binary serialization
category: Serialization, Data
exposed: True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.Streaming
    Data.Store.Streaming.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer
hidden-modules: Data.Store.Impl
abi: a3e2207399fc25e9b5ad29806085d8ce
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/store-0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/store-0.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/store-0.3
hs-libraries: HSstore-0.3-2cBhM2uItiGHgov5En5NW0
depends:
    array-0.5.1.1 async-2.1.1-9CmNvQft9hOA1w6AR7WdJM base-4.9.0.0
    base-orphans-0.5.4-5IQvrjd7gNP548VkOOyIq6
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 conduit-1.2.9-IqfCpUleYsf85Inkwdla2
    containers-0.5.7.1 cryptohash-0.11.9-58MQCkevJarJihmcTE8nlX
    deepseq-1.4.2.0 directory-1.2.6.2 filepath-1.4.1.0
    free-4.12.4-DZCTkfqdDiF4eKUVutuQ1W ghc-prim-0.5.0.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    hspec-2.4.1-EKirEcV3woaAMgIjGSk9Gu
    hspec-smallcheck-0.4.2-LINiTvGwiLeLagundkG6D2 integer-gmp-1.0.0.1
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mono-traversable-1.0.1.2-2UpVXIoqK7WKYUxvseGsp0
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    safe-0.3.14-ALdwhNEer7fKnF5VYCbXfH
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    smallcheck-1.1.1-1P6TVEcRFpCt9hJwyUv6k
    store-core-0.3-DRh8eWR12WHG6VUHAXGWU4
    streaming-commons-0.1.17-JBMCKUjr3AjHIyRG4GSmU7
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    th-lift-0.7.6-3YgW6AFnN6SEjgDav6Czfy
    th-lift-instances-0.1.11-26w65opR3jBHodA1egFP30
    th-orphans-0.13.3-KQRIg7deSjG6NWnqF3AtaQ
    th-reify-many-0.1.6-HIcyW4oKoS86IBXOWG3PUU
    th-utilities-0.2.0.1-ERVRYPERQUC7EwXv1TNX7X time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    void-0.7.1-7ItcNGyWY8l57cMz7KooSQ
haddock-interfaces: /usr/share/doc/haskell-store/html/store.haddock
haddock-html: /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
